@@ -2,16 +2,17 @@ use strict;
 use warnings;
 package App::AppSpec::Schema::Validator;
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use App::Spec;
 use File::Share qw/ dist_file /;
-use YAML::XS;
+use YAML::PP;
 use Moo;
 
 sub validate_spec_file {
     my ($self, $file) = @_;
-    my $spec = YAML::XS::LoadFile($file);
+    my $yp = YAML::PP->new( boolean => 'JSON::PP', schema => [qw/ JSON /] );
+    my $spec = $yp->load_file($file);
     return $self->validate_spec($spec);
 }
 
@@ -19,9 +20,10 @@ sub validate_spec {
     my ($self, $spec) = @_;
     eval { require JSON::Validator }
         or die "JSON::Validator is needed for validating a spec file";
-    my $file = dist_file("App-Spec", "schema.yaml");
-    my $schema = YAML::XS::LoadFile($file);
+    my $schema_file = dist_file("App-Spec", "schema.yaml");
     my $json_validator = JSON::Validator->new;
+    my $yp = YAML::PP->new( boolean => 'JSON::PP', schema => [qw/ JSON /] );
+    my $schema = $yp->load_file($schema_file);
     $json_validator->schema($schema);
     my @errors = $json_validator->validate($spec);
     return @errors;
